@@ -841,7 +841,7 @@ TEMPLATE_PRODUCT_NAME='Rust'
 # rustlib or cargo
 TEMPLATE_REL_MANIFEST_DIR=rustlib
 # 'Rust is ready to roll.' or 'Cargo is cool to cruise.'
-TEMPLATE_SUCCESS_MESSAGE='rust demangler installed.'
+TEMPLATE_SUCCESS_MESSAGE='clippy installed.'
 # Locations to look for directories containing legacy, pre-versioned manifests
 TEMPLATE_LEGACY_MANIFEST_DIRS='rustlib,cargo'
 # The installer version
